@@ -318,6 +318,8 @@ genBlocksModule moduleName = done <$> Fold.foldl' step initial
         , "(Block(..), BlockDefinition(..), block, blockDefinition)"
         , "where"
         , ""
+        , "#include \"MachDeps.h\""
+        , ""
         , "import Data.Ix (Ix)"
         , "import GHC.Exts"
         , ""
@@ -381,9 +383,9 @@ genBlocksModule moduleName = done <$> Fold.foldl' step initial
         , "    getRawCodePoint# k# ="
         , "#ifdef WORDS_BIGENDIAN"
         , "#if MIN_VERSION_base(4,16,0)"
-        , "        byteSwap32# (word32ToWord# (indexWord32OffAddr# addr# k#))"
+        , "        narrow32Word# (byteSwap32# (word32ToWord# (indexWord32OffAddr# ranges# k#)))"
         , "#else"
-        , "        byteSwap32# (indexWord32OffAddr# ranges# k#)"
+        , "        narrow32Word# (byteSwap32# (indexWord32OffAddr# ranges# k#))"
         , "#endif"
         , "#elif MIN_VERSION_base(4,16,0)"
         , "        word32ToWord# (indexWord32OffAddr# ranges# k#)"
@@ -1279,9 +1281,9 @@ genNamesModule moduleName =
         , "    indexInt32OffAddr'# k# ="
         , "#ifdef WORDS_BIGENDIAN"
         , "#if MIN_VERSION_base(4,16,0)"
-        , "        word2Int# (byteSwap32# (word32ToWord# (indexWord32OffAddr# offsets# k#)))"
+        , "        word2Int# (narrow32Word# (byteSwap32# (word32ToWord# (indexWord32OffAddr# offsets# k#))))"
         , "#else"
-        , "        word2Int# (byteSwap32# (indexWord32OffAddr# offsets# k#))"
+        , "        word2Int# (narrow32Word# (byteSwap32# (indexWord32OffAddr# offsets# k#)))"
         , "#endif"
         , "#elif MIN_VERSION_base(4,16,0)"
         , "        int32ToInt# (indexInt32OffAddr# offsets# k#)"
@@ -1329,7 +1331,7 @@ genAliasesModule moduleName =
         , "import Foreign.C.String (CString)"
         , "import GHC.Exts (Ptr(..))"
         , ""
-        , "-- | Type of name alias. See Unicode Standard 14.0.0, section 4.8."
+        , "-- | Type of name alias. See Unicode Standard 15.0.0, section 4.8."
         , "--"
         , "-- @since 0.1.0"
         , "data NameAliasType"
