@@ -222,10 +222,10 @@ generalCategory = toEnum . UC.generalCategory
 and title-case letters, plus letters of caseless scripts and modifiers
 letters).
 
-__Note:__ this function is /not/ equivalent to 'Unicode.Char.General.Compat.isAlpha'
-/'Unicode.Char.General.Compat.isLetter':
+__Note:__ this function is /not/ equivalent to
+'Unicode.Char.General.Compat.isAlpha' / 'Unicode.Char.General.Compat.isLetter':
 
-* 'isAlpha' matches the following general categories:
+* 'Unicode.Char.General.Compat.isAlpha' matches the following general categories:
 
     * 'UppercaseLetter' (@Lu@)
     * 'LowercaseLetter' (@Ll@)
@@ -520,7 +520,7 @@ jamoTLast = jamoTFirst + jamoTCount - 1
 jamoNCount :: Int
 jamoNCount = 588
 
--- hangul
+-- Hangul
 hangulFirst, hangulLast :: Int
 
 -- | Codepoint of the first pre-composed Hangul character.
@@ -542,6 +542,10 @@ isHangul c = n >= hangulFirst && n <= hangulLast
 
 -- | Determine if the given character is a Hangul LV syllable.
 --
+-- __Note:__ this function requires a precomposed Hangul syllable but does /not/
+-- check it. Use 'isHangul' to check the input character before passing it to
+-- 'isHangulLV'.
+--
 -- @since 0.1.0
 isHangulLV :: Char -> Bool
 isHangulLV c = assert (jamoTCount == 28)
